==> kernel-0.9.1.5.3-sources.jar: voxeet/com/sdk/models/HistoryConference.java <==
package voxeet.com.sdk.models;

public class HistoryConference {
    private long conferenceDuration;

    private String conferenceType;

    private String conferenceId;

    private String ownerId;

    private String userId;

    private long conferenceTimestamp;

    private MetaData metadata = new MetaData();

    public String getOwnerId() {
        return ownerId;
    }

    public void setOwnerId(String ownerId) {
        this.ownerId = ownerId;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public long getConferenceDuration() {
        return conferenceDuration;
    }

    public void setConferenceDuration(long conferenceDuration) {
        this.conferenceDuration = conferenceDuration;
    }

    public String getConferenceType() {
        return conferenceType;
    }

    public void setConferenceType(String conferenceType) {
        this.conferenceType = conferenceType;
    }

    public String getConferenceId() {
        return conferenceId;
    }

    public void setConferenceId(String conferenceId) {
        this.conferenceId = conferenceId;
    }

    public long getConferenceTimestamp() {
        return conferenceTimestamp;
    }

    public void setConferenceTimestamp(long conferenceTimestamp) {
        this.conferenceTimestamp = conferenceTimestamp;
    }

    public MetaData getMetadata() {
        return metadata;
    }

    public void setMetadata(MetaData metadata) {
        this.metadata = metadata;
    }
}

==> kernel-0.9.1.5.8.3.9-sources.jar: voxeet/com/sdk/models/HistoryConference.java <==
package voxeet.com.sdk.models;

/**
 * Object mapped from the webservice
 *
 * For future releases, update this class to add new JSON Fields into it
 */
public class HistoryConference {
    private long conferenceDuration;

    private long conferenceRecordingDuration;

    private String conferenceType;

    private String conferenceId;

    private String ownerId;

    private String userId;

    private long conferenceTimestamp;

    private MetaData metadata = new MetaData();

    public String getOwnerId() {
        return ownerId;
    }

    public void setOwnerId(String ownerId) {
        this.ownerId = ownerId;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public long getConferenceDuration() {
        return conferenceDuration;
    }

    public void setConferenceDuration(long conferenceDuration) {
        this.conferenceDuration = conferenceDuration;
    }

    public long getConferenceRecordingDuration() {
        return conferenceRecordingDuration;
    }

    public void setConferenceRecordingDuration(long conferenceRecordingDuration) {
        this.conferenceRecordingDuration = conferenceRecordingDuration;
    }

    public String getConferenceType() {
        return conferenceType;
    }

    public void setConferenceType(String conferenceType) {
        this.conferenceType = conferenceType;
    }

    public String getConferenceId() {
        return conferenceId;
    }

    public void setConferenceId(String conferenceId) {
        this.conferenceId = conferenceId;
    }

    public long getConferenceTimestamp() {
        return conferenceTimestamp;
    }

    public void setConferenceTimestamp(long conferenceTimestamp) {
        this.conferenceTimestamp = conferenceTimestamp;
    }

    public MetaData getMetadata() {
        return metadata;
    }

    public void setMetadata(MetaData metadata) {
        this.metadata = metadata;
    }
}
